summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorMarco Nassabain <marco.nassabain@hotmail.com>2021-03-07 19:29:49 +0100
committerSean Molenaar <SMillerDev@users.noreply.github.com>2021-04-08 22:31:21 +0200
commit0fdd88df550dcac8ce2727461e1810c25021e6eb (patch)
treeb5640ecee055a727d2873de1c98bf42b394586f3 /lib
parenta754b437e08d6ee387a8d2ce9839cce78af17510 (diff)
🧹 ShareService: rename $url to $urlGenerator
Signed-off-by: Marco Nassabain <marco.nassabain@hotmail.com>
Diffstat (limited to 'lib')
-rw-r--r--lib/Service/ShareService.php26
1 files changed, 13 insertions, 13 deletions
diff --git a/lib/Service/ShareService.php b/lib/Service/ShareService.php
index e95fe673b..2b4edafac 100644
--- a/lib/Service/ShareService.php
+++ b/lib/Service/ShareService.php
@@ -49,7 +49,7 @@ class ShareService
/**
* @var IURLGenerator
*/
- private $url;
+ private $urlGenerator;
/**
* @var IL10N
@@ -59,24 +59,24 @@ class ShareService
/**
* ShareService constructor
*
* @param FeedServiceV2 $feedService Service for feeds
* @param ItemServiceV2 $itemService Service to manage items
* @param IURLGenerator $url URL Generator
* @param IL10N $l Localization interface
* @param LoggerInterface $logger Logger
*/
public function __construct(
FeedServiceV2 $feedService,
ItemServiceV2 $itemService,
- IURLGenerator $url,
+ IURLGenerator $urlGenerator,
IL10N $l,
LoggerInterface $logger
) {
- $this->itemService = $itemService;
- $this->feedService = $feedService;
- $this->url = $url;
- $this->l = $l;
- $this->logger = $logger;
+ $this->itemService = $itemService;
+ $this->feedService = $feedService;
+ $this->urlGenerator = $urlGenerator;
+ $this->l = $l;
+ $this->logger = $logger;
}
/**
@@ -107,7 +107,7 @@ class ShareService
$sharedItem->setSharedBy($userId);
// Get 'shared with me' dummy feed
- $feedUrl = $this->url->getBaseUrl() . '/news/sharedwithme';
+ $feedUrl = $this->urlGenerator->getBaseUrl() . '/news/sharedwithme';
$feed = $this->feedService->findByUrl($shareRecipientId, $feedUrl);
if (is_null($feed)) {
$feed = new Feed();
@@ -59,24 +59,24 @@ class ShareService
* ShareService constructor
*
- * @param FeedServiceV2 $feedService Service for feeds
- * @param ItemServiceV2 $itemService Service to manage items
- * @param IURLGenerator $url URL Generator
- * @param IL10N $l Localization interface
- * @param LoggerInterface $logger Logger
+ * @param FeedServiceV2 $feedService Service for feeds
+ * @param ItemServiceV2 $itemService Service to manage items
+ * @param IURLGenerator $urlGenerator URL Generator
+ * @param IL10N $l Localization interface
+ * @param LoggerInterface $logger Logger
*/
public function __construct(